@@ -135,6 +135,7 @@ struct collector_set_ids;
     OVNACT(CT_ORIG_IP6_DST,   ovnact_result)          \
     OVNACT(CT_ORIG_TP_DST,    ovnact_result)          \
     OVNACT(FLOOD_REMOTE,      ovnact_null)            \
+    OVNACT(CT_STATE_SAVE,     ovnact_result)
 
 /* enum ovnact_type, with a member OVNACT_<ENUM> for each action. */
 enum OVS_PACKED_ENUM ovnact_type {
@@ -964,6 +965,8 @@ struct ovnact_encode_params {
                                     *  to resubmit. */
     uint32_t flood_remote_table; /* OpenFlow table for 'chassis_flood'
                                   * to resubmit. */
+    uint32_t ct_state_save_table; /* OpenFlow table for saving ct_state to
+                                   * register. */
 };
 
 void ovnacts_encode(const struct ovnact[], size_t ovnacts_len,
