@@ -33,6 +33,7 @@
 #include "stream.h"
 #include "svec.h"
 #include "unixctl.h"
+#include "dummy.h"
 
 VLOG_DEFINE_THIS_MODULE(ovn_util);
 
@@ -896,8 +897,12 @@ ip_address_and_port_from_lb_key(const char *key, char **ip_address,
  * modified or a stage is added to a logical pipeline.
  *
  * This value is also used to handle some backward compatibility during
- * upgrading. It should never decrease or rewind. */
-#define OVN_INTERNAL_MINOR_VER 6
+ * upgrading. It should never decrease or rewind.
+ *
+ * NOTE: If OVN_NORTHD_PIPELINE_CSUM is updated make sure to double check
+ * whether an update of OVN_INTERNAL_MINOR_VER is required. */
+#define OVN_NORTHD_PIPELINE_CSUM "2978688294 10303"
+#define OVN_INTERNAL_MINOR_VER 8
 
 /* Returns the OVN version. The caller must free the returned value. */
 char *
@@ -1399,3 +1404,18 @@ lport_lookup_by_name(struct ovsdb_idl_index *sbrec_port_binding_by_name,
 
     return retval;
 }
+
+static void
+ovn_enable_timewarp(struct unixctl_conn *conn, int argc OVS_UNUSED,
+                    const char *argv[] OVS_UNUSED, void *arg OVS_UNUSED)
+{
+    timeval_dummy_register();
+    unixctl_command_reply(conn, NULL);
+}
+
+void
+ovn_debug_commands_register(void)
+{
+    unixctl_command_register("debug/enable-timewarp", "", 0, 0,
+                             ovn_enable_timewarp, NULL);
+}
