@@ -343,11 +343,11 @@ Connection commands:\n\
   [--inactivity-probe=MSECS]\n\
   set-connection TARGET...   set the list of connections to TARGET...\n\
 \n\
-SSL commands:\n\
-  get-ssl                     print the SSL configuration\n\
-  del-ssl                     delete the SSL configuration\n\
-  set-ssl PRIV-KEY CERT CA-CERT [SSL-PROTOS [SSL-CIPHERS]] \
-set the SSL configuration\n\
+SSL/TLS commands:\n\
+  get-ssl                     print the SSL/TLS configuration\n\
+  del-ssl                     delete the SSL/TLS configuration\n\
+  set-ssl PRIV-KEY CERT CA-CERT [SSL-PROTOS [SSL-CIPHERS [SSL-CIPHERSUITES]]] \
+set the SSL/TLS configuration\n\
 \n\
 %s\
 %s\
@@ -697,11 +697,14 @@ cmd_set_ssl(struct ctl_context *ctx)
 
     icnbrec_ssl_set_bootstrap_ca_cert(ssl, bootstrap);
 
-    if (ctx->argc == 5) {
+    if (ctx->argc >= 5) {
         icnbrec_ssl_set_ssl_protocols(ssl, ctx->argv[4]);
-    } else if (ctx->argc == 6) {
-        icnbrec_ssl_set_ssl_protocols(ssl, ctx->argv[4]);
-        icnbrec_ssl_set_ssl_ciphers(ssl, ctx->argv[5]);
+        if (ctx->argc >= 6) {
+            icnbrec_ssl_set_ssl_ciphers(ssl, ctx->argv[5]);
+            if (ctx->argc == 7) {
+                icnbrec_ssl_set_ssl_ciphersuites(ssl, ctx->argv[6]);
+            }
+        }
     }
 
     icnbrec_ic_nb_global_set_ssl(ic_nb_global, ssl);
@@ -1020,11 +1023,12 @@ static const struct ctl_command_syntax ic_nbctl_commands[] = {
     {"set-connection", 1, INT_MAX, "TARGET...", pre_connection,
         cmd_set_connection, NULL, "--inactivity-probe=", RW},
 
-    /* SSL commands. */
+    /* SSL/TLS commands. */
     {"get-ssl", 0, 0, "", pre_cmd_get_ssl, cmd_get_ssl, NULL, "", RO},
     {"del-ssl", 0, 0, "", pre_cmd_del_ssl, cmd_del_ssl, NULL, "", RW},
-    {"set-ssl", 3, 5,
-        "PRIVATE-KEY CERTIFICATE CA-CERT [SSL-PROTOS [SSL-CIPHERS]]",
+    {"set-ssl", 3, 6,
+        "PRIVATE-KEY CERTIFICATE CA-CERT"
+        " [SSL-PROTOS [SSL-CIPHERS [SSL-CIPHERSUITES]]]",
         pre_cmd_set_ssl, cmd_set_ssl, NULL, "--bootstrap", RW},
 
     {NULL, 0, 0, NULL, NULL, NULL, NULL, NULL, RO},
